@@ -3,7 +3,7 @@
 '''
 A library to access Tryton's models like a client.
 '''
-__version__ = "2.6.1"
+__version__ = "2.6.2"
 __all__ = ['Model', 'Wizard']
 import sys
 try:
@@ -586,6 +586,9 @@ class Model(object):
     @classmethod
     def get(cls, name, config=None):
         'Get a class for the named Model'
+        if isinstance(name, unicode):
+            name = name.encode('utf-8')
+
         class Spam(Model):
             __metaclass__ = MetaModelFactory(name, config=config)()
         return Spam
@@ -879,7 +882,7 @@ class Wizard(object):
         assert state in self.states
 
         self.state = state
-        while self.state != 'end':
+        while self.state != self.end_state:
             ctx = self._context.copy()
             ctx.update(self._config.context)
             if self.models:
